@@ -8,7 +8,7 @@
 #' @name AssessmentItem-class
 #' @rdname AssessmentItem-class
 #' @aliases AssessmentItem
-#' @include ModalFeedback.R rqti.R
+#' @include ModalFeedback.R rqti.R QtiMetadata.R
 setClass("AssessmentItem", slots = c(identifier = "character",
                                      title = "character",
                                      content = "list",
@@ -17,10 +17,9 @@ setClass("AssessmentItem", slots = c(identifier = "character",
                                      feedback = "list",
                                      files = "character",
                                      calculator = "character",
-                                     qti_version = "character"),
+                                     metadata = "QtiMetadata"),
          prototype = prototype(prompt = "",
-                               points = 1,
-                               qti_version = "v2p1"))
+                               points = 1))
 
 setMethod("initialize", "AssessmentItem", function(.Object, ...) {
     .Object <- callNextMethod()
@@ -44,7 +43,7 @@ setMethod("initialize", "AssessmentItem", function(.Object, ...) {
 #' specification the question following the QTI schema v2.1
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair])
 #' @docType methods
 #' @rdname createItemBody-methods
@@ -56,7 +55,7 @@ setGeneric("createItemBody", function(object) standardGeneric("createItemBody"))
 #' specification the question following the QTI schema v2.1
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @docType methods
@@ -70,7 +69,7 @@ setGeneric("createResponseDeclaration",
 #' specification the question following the QTI schema v2.1
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @docType methods
@@ -84,7 +83,7 @@ setGeneric("createOutcomeDeclaration",
 #' specification the question following the QTI schema v2.1
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @docType methods
@@ -96,7 +95,7 @@ setGeneric("createResponseProcessing",
 #'
 #' @usage createQtiTask(object, dir = NULL, verification = FALSE)
 #' @param object An instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair]).
 #' @param dir A character value, optional; a folder to store xml file; working
 #'   directory is used by default.
@@ -156,7 +155,7 @@ setGeneric("createQtiTest",
 #' Get points from AssessmentItem object
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @name getPoints-methods
@@ -168,7 +167,7 @@ setGeneric("getPoints", function(object) standardGeneric("getPoints"))
 #' Get identifier
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @name getIdentifier-methods
@@ -180,7 +179,7 @@ setGeneric("getIdentifier", function(object) standardGeneric("getIdentifier"))
 #' Get object
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @name getObject-methods
@@ -217,7 +216,7 @@ setGeneric("buildAssessmentSection",
 #' Get file paths for attachment of test
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @name getFiles-methods
@@ -229,7 +228,7 @@ setGeneric("getFiles", function(object) standardGeneric("getFiles"))
 #' Get value of the slot 'calculator'
 #'
 #' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
-#'   [Essay], [Entry], [Order], [OneInRowTable], [OneInColTable],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
 #'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
 #'   [InlineChoice])
 #' @name getCalculator-methods
@@ -251,6 +250,25 @@ setGeneric("getCalculator", function(object) standardGeneric("getCalculator"))
 setGeneric("prepareQTIJSFiles",
            function(object, dir = NULL) standardGeneric("prepareQTIJSFiles"))
 
+#' Get list of contributors values
+#'
+#' @param object an instance of the S4 object ([SingleChoice], [MultipleChoice],
+#'   [Essay], [Entry], [Ordering], [OneInRowTable], [OneInColTable],
+#'   [MultipleChoiceTable], [DirectedPair], [TextGap], [NumericGap],
+#'   [InlineChoice])
+#' @name getContributors-methods
+#' @rdname getContributors-methods
+#' @aliases getContributors
+#' @docType methods
+setGeneric("getContributors", function(object) standardGeneric("getContributors"))
+
+#' @rdname getContributors-methods
+#' @aliases getContributors,AssessmentItem
+setMethod("getContributors", signature(object = "AssessmentItem"),
+          function(object) {
+              return(object@metadata@contributor)
+          })
+
 #' @rdname createQtiTask-methods
 #' @aliases createQtiTask,AssessmentItem
 setMethod("createQtiTask", signature(object = "AssessmentItem"),
@@ -363,5 +381,13 @@ setMethod("getCalculator", signature(object = "AssessmentItem"),
 #' @aliases prepareQTIJSFiles,AssessmentItem
 setMethod("prepareQTIJSFiles", signature(object = "AssessmentItem"),
           function(object, dir = "") {
-              createQtiTask(object, file.path(dir, "index.xml"))
+              suppressMessages(createQtiTask(object,
+                                             file.path(dir, "index.xml")))
+          })
+
+#' @rdname createMetadata-methods
+#' @aliases createMetadata,AssessmentItem
+setMethod("createMetadata", signature(object = "AssessmentItem"),
+          function(object) {
+              create_metadata(object)
           })
