@@ -156,3 +156,12 @@ setMethod("prepareQTIJSFiles", signature(object = "AssessmentSection"),
               prepareQTIJSFiles(tst, dir)
               return(NULL)
           })
+
+#' @rdname getContributors-methods
+#' @aliases getContributors,AssessmentSection
+setMethod("getContributors", signature(object = "AssessmentSection"),
+          function(object) {
+              result <- unlist(sapply(object@assessment_item, getContributors))
+              return(result)
+          })
+
